@@ -3,7 +3,7 @@
 Company: eXonware.com
 Author: Eng. Muhammad AlShehri
 Email: connect@exonware.com
-Version: 0.0.1.355
+Version: 0.0.1.365
 Generation Date: September 10, 2025
 
 XWSystem - Enterprise-grade Python framework with AI-powered performance optimization.
@@ -57,6 +57,82 @@ from typing import TYPE_CHECKING
 if TYPE_CHECKING:
     from typing import Any
 
+# Lazy mode utilities
+from .utils.lazy_loader import (
+    LazyLoader,
+    LazyModuleRegistry,
+    LazyModeFacade,
+    LazyPerformanceMonitor,
+    register_lazy_module,
+    get_lazy_module,
+    get_loading_stats,
+    preload_frequently_used,
+    enable_lazy_mode,
+    disable_lazy_mode,
+    is_lazy_mode_enabled,
+    get_lazy_mode_stats,
+    configure_lazy_mode,
+    preload_modules,
+    optimize_lazy_mode
+)
+
+# =============================================================================
+# LAZY INSTALLATION - Simple One-Line Configuration
+# =============================================================================
+# Auto-detects if user installed with [lazy] extra: pip install xwsystem[lazy]
+from .utils.lazy_discovery import config_package_lazy_install_enabled
+config_package_lazy_install_enabled("xwsystem")  # Auto-detect from installation
+
+# Lazy install utilities
+from .utils.lazy_install import (
+    LazyInstaller,
+    LazyInstallerRegistry,
+    LazyInstallMode,
+    LazyInstallPolicy,
+    DependencyMapper,
+    enable_lazy_install,
+    disable_lazy_install,
+    is_lazy_install_enabled,
+    set_lazy_install_mode,
+    get_lazy_install_mode,
+    install_missing_package,
+    install_and_import,
+    get_lazy_install_stats,
+    get_all_lazy_install_stats,
+    lazy_import_with_install,
+    xwimport,
+    # Security & Policy APIs
+    set_package_allow_list,
+    set_package_deny_list,
+    add_to_package_allow_list,
+    add_to_package_deny_list,
+    set_package_index_url,
+    set_package_extra_index_urls,
+    add_package_trusted_host,
+    set_package_lockfile,
+    generate_package_sbom,
+    check_externally_managed_environment
+)
+
+# Lazy discovery utilities
+from .utils.lazy_discovery import (
+    LazyDiscovery,
+    LazyInstallConfig,
+    DependencyInfo,
+    discover_dependencies,
+    get_lazy_discovery,
+    export_dependency_mappings,
+    config_package_lazy_install_enabled
+)
+
+# Lazy import hook utilities (performance optimized)
+from .utils.lazy_import_hook import (
+    LazyMetaPathFinder,
+    install_import_hook,
+    uninstall_import_hook,
+    is_import_hook_installed
+)
+
 # Logging utilities
 from .config.logging_setup import get_logger, setup_logging
 
@@ -100,7 +176,7 @@ from .serialization import (
     FeatherSerializer, FeatherError,
     GraphDbSerializer, GraphDbError,
     # Intelligent auto-detection
-    XWSerialization, dumps, loads, save_file, load_file,
+    XWSerializer, dumps, loads, save_file, load_file,
     # Flyweight optimization
     get_serializer, get_flyweight_stats, clear_serializer_cache, 
     get_cache_info, create_serializer, SerializerPool,
@@ -264,8 +340,7 @@ from .config import (
     PATH_SEPARATOR_FORWARD, PATH_SEPARATOR_BACKWARD,
     CIRCULAR_REFERENCE_PLACEHOLDER, MAX_DEPTH_EXCEEDED_PLACEHOLDER,
     LOGGING_ENABLED, LOGGING_LEVEL, setup_logging, get_logger,
-    PerformanceMode, PerformanceProfile, PerformanceProfiles,
-    PerformanceModeManager, PerformanceConfig, PerformanceLimits,
+    PerformanceConfig, PerformanceLimits,
     SerializationLimits, NetworkLimits, SecurityLimits
 )
 from .config.performance import (
@@ -409,8 +484,8 @@ def quick_deserialize(data, format="auto", **kwargs):
         {'hello': 'world'}
     """
     if format == "auto":
-        from .serialization import XWSerialization
-        return XWSerialization().loads(data, **kwargs)
+        from .serialization import XWSerializer
+        return XWSerializer().loads(data, **kwargs)
     else:
         from .serialization import create_serializer
         serializer = create_serializer(format)
@@ -573,7 +648,7 @@ __all__ = [
     "FeatherSerializer", "FeatherError",
     "GraphDbSerializer", "GraphDbError",
     # Intelligent auto-detection
-    "XWSerialization", "dumps", "loads", "save_file", "load_file",
+    "XWSerializer", "dumps", "loads", "save_file", "load_file",
     # Flyweight optimization
     "get_serializer", "get_flyweight_stats", "clear_serializer_cache", 
     "get_cache_info", "create_serializer", "SerializerPool",
@@ -688,11 +763,9 @@ __all__ = [
     "PATH_SEPARATOR_BACKWARD",
     "CIRCULAR_REFERENCE_PLACEHOLDER",
     "MAX_DEPTH_EXCEEDED_PLACEHOLDER",
-    # Performance Modes
-    "PerformanceMode",
-    "PerformanceProfile",
-    "PerformanceProfiles",
-    "PerformanceModeManager",
+    # Performance Configuration
+    "PerformanceConfig",
+    "PerformanceLimits",
     # Validation
     "DataValidator",
     "check_data_depth",
@@ -847,6 +920,67 @@ __all__ = [
     "Pipe",
     "AsyncPipe",
     
+    # Lazy Mode - Performance optimization
+    "LazyLoader",
+    "LazyModuleRegistry", 
+    "LazyModeFacade",
+    "LazyPerformanceMonitor",
+    "register_lazy_module",
+    "get_lazy_module",
+    "get_loading_stats",
+    "preload_frequently_used",
+    "enable_lazy_mode",
+    "disable_lazy_mode",
+    "is_lazy_mode_enabled",
+    "get_lazy_mode_stats",
+    "configure_lazy_mode",
+    "preload_modules",
+    "optimize_lazy_mode",
+    
+    # Lazy Install - Auto-install missing packages (per-package isolation)
+    "LazyInstaller",
+    "LazyInstallerRegistry",
+    "LazyInstallMode",
+    "LazyInstallPolicy",
+    "DependencyMapper",
+    "enable_lazy_install",
+    "disable_lazy_install",
+    "is_lazy_install_enabled",
+    "set_lazy_install_mode",
+    "get_lazy_install_mode",
+    "install_missing_package",
+    "install_and_import",
+    "get_lazy_install_stats",
+    "get_all_lazy_install_stats",
+    "lazy_import_with_install",
+    "xwimport",
+    # Security & Policy APIs
+    "set_package_allow_list",
+    "set_package_deny_list",
+    "add_to_package_allow_list",
+    "add_to_package_deny_list",
+    "set_package_index_url",
+    "set_package_extra_index_urls",
+    "add_package_trusted_host",
+    "set_package_lockfile",
+    "generate_package_sbom",
+    "check_externally_managed_environment",
+    
+    # Lazy Discovery - Package-agnostic dependency discovery with auto-detection
+    "LazyDiscovery",
+    "LazyInstallConfig",
+    "DependencyInfo",
+    "discover_dependencies",
+    "get_lazy_discovery",
+    "export_dependency_mappings",
+    "config_package_lazy_install_enabled",
+    
+    # Lazy Import Hook - Performance optimized automatic import interception
+    "LazyMetaPathFinder",
+    "install_import_hook",
+    "uninstall_import_hook",
+    "is_import_hook_installed",
+    
     # Convenience Functions - Quick access patterns
     "quick_serialize",
     "quick_deserialize", 
